@@ -42,6 +42,14 @@ pub mod email_auth_request;
 pub use self::email_auth_request::EmailAuthRequest;
 pub mod error_detail;
 pub use self::error_detail::ErrorDetail;
+pub mod event;
+pub use self::event::Event;
+pub mod event_request;
+pub use self::event_request::EventRequest;
+pub mod event_source;
+pub use self::event_source::EventSource;
+pub mod event_status;
+pub use self::event_status::EventStatus;
 pub mod experiment;
 pub use self::experiment::Experiment;
 pub mod experiment_device_config;
@@ -180,6 +188,8 @@ pub mod paginated_task_status_list;
 pub use self::paginated_task_status_list::PaginatedTaskStatusList;
 pub mod paginated_telemetry_event_polymorphic_list;
 pub use self::paginated_telemetry_event_polymorphic_list::PaginatedTelemetryEventPolymorphicList;
+pub mod paginated_test_event_list;
+pub use self::paginated_test_event_list::PaginatedTestEventList;
 pub mod partner3_d_geeks_alert;
 pub use self::partner3_d_geeks_alert::Partner3DGeeksAlert;
 pub mod partner3_d_geeks_metadata;
@@ -288,6 +298,12 @@ pub mod telemetry_event_polymorphic_request;
 pub use self::telemetry_event_polymorphic_request::TelemetryEventPolymorphicRequest;
 pub mod telemetry_event_request;
 pub use self::telemetry_event_request::TelemetryEventRequest;
+pub mod test_event;
+pub use self::test_event::TestEvent;
+pub mod test_event_request;
+pub use self::test_event_request::TestEventRequest;
+pub mod test_event_type;
+pub use self::test_event_type::TestEventType;
 pub mod token_response;
 pub use self::token_response::TokenResponse;
 pub mod user;
